/* Includes ------------------------------------------------------------------*/
#include "RTC.h"



/*************************************************************************************
Name:RTC_Reset
Purpose:Forces or releases the RTC peripheral and associated resources reset
Paramenters:uint8_t NewState,the value must be 0 or 1
Return:no
**************************************************************************************/
void RTC_Reset(uint8_t NewState)
{
    if(NewState)
    {
        CMU_PCLKCR1->Bits.RTCA_PCE = 1;                     //RTCAʱ
        RTCA_CR->Bits.EN = 1;                               //ʹRTCA
    }
    else
    {
        CMU_PCLKCR1->Bits.RTCA_PCE = 0;                     //رRTCAʱ
        RTCA_CR->Bits.EN = 0;                               //رRTCA(ڲʱʱӹر)
    }
}



/****************************************************************************************
Name:RTC_SetTime
Purpose:set the RTC calendar
Paramenters:RTC_Calendar struct point
Return:no
*****************************************************************************************/
void RTC_SetTime(DATETIME* Calendar_Point)
{
    RTCA_WER->All = 0xACACACAC;                             //RTCAдʹ
    RTCA_BCDSEC->Bits.SEC = Calendar_Point->Second;         //дʱԶڼʵͬ
    RTCA_BCDMIN->Bits.MIN = Calendar_Point->Minute;
    RTCA_BCDHOUR->Bits.HOUR = Calendar_Point->Hour;
    RTCA_BCDDAY->Bits.DAY = Calendar_Point->Day;
    RTCA_BCDMONTH->Bits.MONTH = Calendar_Point->Month;
    RTCA_BCDYEAR->Bits.YEAR = Calendar_Point->Year[1];
    RTCA_WER->All = 0x5A5A5A5A;                             //RTCAдֹ
}



/****************************************************************************************
Name:RTC_GetDateTime
Purpose:set the RTC calendar
Paramenters:RTC_Calendar struct point
Return:no
*****************************************************************************************/
void RTC_ReadTime(DATETIME* rtcTime)
{
    rtcTime->Second = RTCA_BCDSEC->Bits.SEC;                                    //ȡ
    rtcTime->Minute = RTCA_BCDMIN->Bits.MIN;                                    //ȡ
    rtcTime->Hour = RTCA_BCDHOUR->Bits.HOUR;                                    //ȡʱ
    rtcTime->Day = RTCA_BCDDAY->Bits.DAY;                                       //ȡ
//    rtcTime->Week = RTCA_BCDWEEK->Bits.WEEK;                                  //ȡ
    rtcTime->Month = RTCA_BCDMONTH->Bits.MONTH;                                 //ȡ
    rtcTime->Year[1] = RTCA_BCDYEAR->Bits.YEAR;                                 //ȡ
}


int16_t RTC_GetDateTime(DATETIME* Calendar_Point)
{
    uint8_t n, i;
    ErrorStatus status = FAIL;
    DATETIME tmpTime1, tmpTime2;
    
    for(n=0 ;n<3; n++)                                                          //ظ3
    {
        RTC_ReadTime(&tmpTime1);                                                //һʱ
        RTC_ReadTime(&tmpTime2);                                                //ٶһʱ
        for(i=1; i<7; i++)                                                      //һ, ʾȡɹ
        {
            if(((uint8_t*)(&tmpTime1))[i] != ((uint8_t*)(&tmpTime2))[i])break;
        }
        if(i == 7)
        {
            status = PASS;
            memcpy((uint8_t*)Calendar_Point, (uint8_t*)&tmpTime1, 7*sizeof(uint8_t));    //ȡȷµʱ
            break;
        }
    }
    return status;
}


/********************************************************************************************
Name:RTC_SetAlarm
Purpose:set Alarm time
Paramenters: RTC_alarm: RTC_Alarm_A/RTC_Alarm_B
             Alarm_struct,the alarm time struct
Return:no
*********************************************************************************************/
//Сʱ
void RTC_SetAlarm(uint32_t RTC_alarm, RTC_Alarm_TypeDef* Alarm_struct)
{
    RTCA_ALARM->Bits.HOUR = Alarm_struct->hour;
    RTCA_ALARM->Bits.MIN = Alarm_struct->min;
    RTCA_ALARM->Bits.SEC = Alarm_struct->sec;
}

/***********************************************************************************
Name:RTC_EnableCount
Purpose:enable the RTC to count
Paramenters:no
Return:no
************************************************************************************/
void RTC_EnableCount(void)
{
    RTCA_CR->Bits.EN = 1;
}


/***************************************************************************************
Name:RTC_AlarmITEnable
Purpose:enable the RTC Alarm interrupt
Paramenters:RTC_Alarm_A/RTC_Alarm_B
Return:no
****************************************************************************************/
void RTC_AlarmITEnable(uint32_t RTC_alarm)
{
    RTCA_ISR->Bits.ALARM_IF = 1;                            //жϱ־
    RTCA_IER->Bits.ALARM_IE = 1;                            //ʹж
//    RTCA_ISR->Bits.HOUR_IF = 1;                             //Сʱжϱ־
//    RTCA_IER->Bits.HOUR_IE = 1;                             //ʹСʱж
}


/********************************************************************************************
Name:RTC_InitCalendar
Purpose:set the RTC calendar
Paramenters:Calendar_Point:RTC_Calendar struct point
Return:no
*********************************************************************************************/
void RTC_InitCalendar(DATETIME * Calendar_Point)
{
    RTCA_WER->All = 0xACACACAC;
    RTCA_BCDSEC->Bits.SEC = Calendar_Point->Second;
    RTCA_BCDMIN->Bits.MIN = Calendar_Point->Minute;
    RTCA_BCDHOUR->Bits.HOUR = Calendar_Point->Hour;
    RTCA_BCDDAY->Bits.DAY = Calendar_Point->Day;
    RTCA_BCDMONTH->Bits.MONTH = Calendar_Point->Month;
    RTCA_BCDYEAR->Bits.YEAR = Calendar_Point->Year[1];
    RTCA_WER->All = 0x5A5A5A5A;
}



/*********************************************************************************************
Name:RTC_WakeupInit
Purpose:
Paramenter:
Return:
**********************************************************************************************/
void RTC_WakeupInit(INT16 period)
{
    
}

//500ms/100ms/50msʱMCUϵͳʱӽ
BOOL setSysTick(INT16 SysWakeInterval)
{
    
}

/*********************************************************************************************
Name:RTC_WakeupInterruptEN
Purpose:enable the wakeup interrupt
Paramenters:no
Return:no
**********************************************************************************************/
void RTC_WakeupInterruptEN(void)
{
    
}

/******************************************************************************************
Name:RTC_WakeupEN
Purpose:enable the wakeup timer counter
Paramenters:no
Return:no
*******************************************************************************************/
void RTC_WakeupEN(void)
{
    
}

/******************************************************************************************
Name:SetRTCCalibration
Purpose:set the RTC calibration value
Paramenter:RTC_Plus_set:1:increase 512 clk per 2^20 RTCCLK pulses;0:no clk increase
           RTC_Cal:0~511,decrease the specific clk per 2^20 RTCCLK pulses
Return:no
*******************************************************************************************/
void SetRTCCalibration(INT8U RTC_Plus_set,INT16U RTC_Cal)
{
    
}


void RTCWakeup(void)
{

}

//λRTC裬RTCʱӻģʽ
/***************************************************************************************
Name:RTCClockRecover
Purpose:reset the RTC domain,change the RTC clock from LSI to LSE,reconfig the RTC
Paramenters:no
Return:no
****************************************************************************************/
INT16 RTCClockRecover(void)
{
    
}

/***************************************************************************************
Name:RTCLSEToLSI
Purpose:change the RTC clock from LSE to LSI
Paramenters:no
Return:no
****************************************************************************************/
void RTCLSEToLSI(void)
{

}



